@@ -7,6 +7,7 @@ from pymongo import MongoClient
 from termcolor2 import colored
 import os
 from dotenv import load_dotenv
+import load_config
 warnings.filterwarnings("ignore")
 
 
@@ -17,9 +18,9 @@ class MongoLoader:
         self.bi_department = bi_departement
         self.date = date
         load_dotenv()
-        self.db_conf = os.getenv('DB_CONFIG')
-        kp_path = os.getenv('KEYPASS')
-        conf_r = os.getenv('ENTITY_CONFIGS')
+        self.db_conf = load_config.get_db_config()
+        kp_path = load_config.get_keypass_config()
+        conf_r = load_config.get_entity_configs()
 
 
     def writereport(self, report_data: pd.DataFrame):
