@@ -4,6 +4,7 @@ import os
 import pandas as pd
 import yaml
 from dotenv import load_dotenv
+import load_config
 
 
 
@@ -11,9 +12,9 @@ from dotenv import load_dotenv
 def add_technical_col(data: pd.DataFrame, t_name: str, date: str = None, entity_name: str = None,
                       buildHashKey: bool = False):
     load_dotenv()
-    db_conf = os.getenv('DB_CONFIG')
-    kp_path = os.getenv('KEYPASS')
-    conf_r = os.getenv('ENTITY_CONFIGS')
+    db_conf = load_config.get_db_config()
+    kp_path = load_config.get_keypass_config()
+    conf_r = load_config.get_entity_configs()
     conf = os.path.join(conf_r, '{entity}.yaml'.format(entity=entity_name))
     with open(conf) as file:
         documents = yaml.full_load(file)
