@@ -6,6 +6,7 @@ from dotenv import load_dotenv
 from pykeepass import PyKeePass
 from sqlalchemy.engine import create_engine
 from sshtunnel import SSHTunnelForwarder
+import load_config
 
 
 def connect_to_db(layer: str = None):
@@ -16,8 +17,9 @@ def connect_to_db(layer: str = None):
     :return: databse connection (mariadb)
     '''
     load_dotenv()
-    config_file = '/opt/airflow/dags/Configs/Global/db.yaml' #os.getenv('DB_CONFIG')
-    kp_path = '/opt/airflow/dags/Configs/dwh.kdbx' #os.getenv('KEYPASS')
+    load_config.get_db_config()
+    config_file = load_config.get_db_config()
+    kp_path = load_config.get_keypass_config()
 
     with open(config_file) as file:
         documents = yaml.full_load(file)
