@@ -8,13 +8,14 @@ from sqlalchemy import MetaData
 from sqlalchemy import create_engine
 import os
 from dotenv import load_dotenv
+import load_config
 
 
 def load(data: pd.DataFrame, db_con, t_name: str, date: str, schema: str = None, commit_size: int = 10000):
     load_dotenv()
-    config_file = os.getenv('DB_CONFIG')
-    kp_path = os.getenv('KEYPASS')
-    conf_r = os.getenv('ENTITY_CONFIGS')
+    config_file = load_config.get_db_config()
+    kp_path = load_config.get_keypass_config()
+    conf_r = load_config.get_entity_configs()
     con_s = "mysql+pymysql://root:123456@82.165.203.114:3306/src?charset=utf8mb4"  # 'postgresql://postgres:123456@OKRAMER-MAC:5432/BANK'
     con = create_engine(con_s, echo=False, pool_recycle=3600)
     temp_table = t_name + time.time().__str__()
