@@ -1,4 +1,7 @@
-import pika, sys, os
+import os
+import pika
+import sys
+
 
 def main():
     connection = pika.BlockingConnection(pika.ConnectionParameters(host='localhost'))
@@ -14,6 +17,7 @@ def main():
     print(' [*] Waiting for messages. To exit press CTRL+C')
     channel.start_consuming()
 
+
 if __name__ == '__main__':
     try:
         main()
@@ -22,4 +26,4 @@ if __name__ == '__main__':
         try:
             sys.exit(0)
         except SystemExit:
-            os._exit(0)
\ No newline at end of file
+            os._exit(0)
