@@ -1,6 +1,6 @@
 import pika
 import pandas as pd
-from project.dags.utils.ReadEntity import ReadEntity
+from dwhutils.ReadEntity import ReadEntity
 
 p_date = '2018-12-31'
 trans = ReadEntity(p_date=p_date, layer='biz', entity_name='transaktion').read_entity
